#
# spec file for package python-GitPython
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-GitPython
Version:        3.0.5
Release:        bp153.1.18
Summary:        Python Git Library
License:        BSD-3-Clause
URL:            https://github.com/gitpython-developers/GitPython
Source:         GitPython-%{version}.tar.gz
Patch0:         test-skips.patch
Patch1:         test_blocking_lock_file-extra-time.patch
BuildRequires:  %{python_module ddt >= 1.1.1}
BuildRequires:  %{python_module gitdb2 >= 2.0.0}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module smmap2 >= 2.0.0}
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  python-rpm-macros
BuildRequires:  python2-mock
Requires:       git-core
Requires:       python-gitdb2 >= 2.0.0
BuildArch:      noarch
%python_subpackages

%description
GitPython is a python library used to interact with Git repositories.

GitPython provides object model read and write access to your git repository.
Access repository information conveniently, alter the index directly, handle
remotes, or go down to low-level object database access with big-files support.

With the new object database abstraction added in 0.3, its even possible to
implement your own storage mechanisms, the currently available implementations
are 'cgit' and pure python, which is the default.

%prep
%setup -q -n GitPython-%{version}
echo y | ./init-tests-after-clone.sh
%autopatch -p1
# do not pull in extra deps
sed -i -e '/tox/d' -e '/flake8/d' -e '/coverage/d' test-requirements.txt

%build
%python_build

%install
%python_install
%python_expand rm -r %{buildroot}%{$python_sitelib}/git/test/
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# While SKIP_GITHUB is fine, the two tests skipped with SKIP_LOCALHOST
# should work as the test runner sets up a git daemon.
export SKIP_GITHUB=true
export SKIP_LOCALHOST=true
export TRAVIS=true

export LANG=en_US.UTF-8
export GIT_PYTHON_TEST_GIT_REPO_BASE=${PWD}

git config --global user.email "you@example.com"
git config --global user.name "Your Name"

%python_exec setup.py test --test-suite=git.test

%files %{python_files}
%license LICENSE
%doc AUTHORS CHANGES README.md doc/source/*.rst
%dir %{python_sitelib}/git
%{python_sitelib}/git/*
%dir %{python_sitelib}/GitPython-%{version}-py*.egg-info
%{python_sitelib}/GitPython-%{version}-py*.egg-info

%changelog
* Sat Nov 16 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * be more explicit in %%files section
  * updated line numbers in patches
- update to version 3.0.5:
  * Remove duplicate license parameter
  * Fix/deepsource issues
  * Check if submodule exists before referencing
  * Fix cloning to path with unicode
  * Global ConfigParser
  * Fix 'PushInfo' object has no attribute 'name'
  * Reading and writing global configuration parameters acknowledged
    help wanted
  * Added Git Gud to projects
  * Git.AutoInterrupt.__del__() OSError: [WinError 6] The handle is
    invalid acknowledged help wanted tag.Windows
- changes from version 3.0.4:
  * Fix repo.index.diff("HEAD", create_patch=True) always returning an
    empty list
  * Fix how Diff handles commits that contain submodule changes
  * Fix pickling of tzoffset
  * Add support for 'C'-type diffs
  * Fixed#731
  * Update .deepsource.toml
  * Allow single item for index.addremovemove
* Mon Oct  7 2019 tchvatal@suse.com
- Update to version 3.0.3.1570041589.23b83cd:
  * Prepare v3.0.3
  * git: repo: base: update clone_from env argument description
  * remove previously added debug code from test_doc.py
  * Revert "Remove control character stripping."
  * Try to fix tests; get more debug output
  * Update util.py
  * Update util.py
  * Remove control character stripping.
  * add type check to git.Remote.__eq__
  * Take advantage of universal newlines.
  * Parse rejected deletes.
  * Remove assert that can fail erroneously.
  * Fix test_commit_msg_hook_success.
  * fix decoding problem
  * Fix #889: Add DeepSource config and fix some major issues
* Tue Sep 24 2019 tchvatal@suse.com
- Update to version 3.0.2.1566444429.0765792:
  * prepare next release
  * BF: remove ddt from requirements.txt since no ddt required at run time.
  * Bump version to 3.0.1
  * Remove dependency on 'gitdb'; fixes #908
  * Changelog information
  * Adding test
  * Returning commit object instead of hash value
  * Snack case as requested in #903
  * Method stating which commit is being played during an halted rebase
  * Fix performance regression, see #906
- Drop merged patch merged_pr_793.patch
- Rebase patch test-skips.patch
* Fri Mar 15 2019 tchvatal@suse.com
- Update to version 2.1.11.1531661757.92a4819:
  * Bump version to 2.1.11
  * fix whitespace violation
  * Update test_docs.py
  * Dedent code blocks in tutorial.
  * Allow pathlib.Path in Repo.__init__
  * Fix small typo
  * Fix exception on import in MacOS
  * Bump to 2.1.10
  * Add change in type support
  * Get correcly rename change_type.
- Simplify the service file and generating of the tarball
  and base everything on a tag
* Wed Mar 13 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite and remove bcond test
- Add merged_pr_793.patch already merged upstream to fix Python 3.7,
  especially git submodules
- Add test_blocking_lock_file-extra-time.patch to avoid an
  indeterministic timing failure
- Add test-skips.patch to skip one expected failure and workaround
  two unknown failures
- Remove test suite from the runtime package
- Add doc/source/*.rst to %%docs
- Remove dependency on python3-mock
- Set build dependency ddt minimum version 1.1.1
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Sep 27 2018 comurphy@suse.com
- Require git-core instead of git
* Tue Aug  7 2018 toddrme2178@gmail.com
- update to 2.1.11
  * Update test_docs.py
  * Dedent code blocks in tutorial.
  * Exception when constructing a Repo() from a pathlib.Path acknowledged help wanted
  * Allow pathlib.Path in Repo.__init__
  * Fix exception on import in MacOS
  * Failed import raises non-ImportError exception on MacOS
- update to 2.1.10
  * Fix rename change type & support 'change in type' acknowledged
  * Configurable chunk size
  * Avoid from_timestamp() function to raise an exception when the offset…
  * Adding files to repository that is located directly in the root acknowledged
  * git: index: base: use os.path.relpath
* Sat Apr 14 2018 arun@gmx.de
- update to version 2.1.9:
  * Drop support for EOL Python 2.6 and 3.3
  * Allow mmap not just for py2.6, 2.7 and 3.6+ but also 3.0+
  * Fix doc typos
* Wed Jan 17 2018 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 2.1.8
  * bugfixes
- Update to version 2.1.6
  * bugfixes
  * support for worktrees
- Update to version 2.1.3
  * bugfixes
- Update to version 2.1.1
  * bugfixes
- Update to version 2.1.0
  * Much better windows support!
  * The `GIT_DIR` environment variable does not override the `path` argument when
    initializing a `Repo` object anymore. However, if said `path` unset, `GIT_DIR`
    will be used to fill the void.
- Update to version 2.0.9
  * Bugfixes
  * `tag.commit` will now resolve commits deeply.
  * `Repo` objects can now be pickled, which helps with multi-processing.
  * `Head.checkout()` now deals with detached heads, which is when it will return
    the `HEAD` reference instead.
  * `DiffIndex.iter_change_type(...)` produces better results when diffing
* Wed Aug 31 2016 dmueller@suse.com
- update to 2.0.8:
  * Py2.6 support dropped
  * lots of new features and bugfixes
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 1.0.1:
  * A list of all issues can be found on github
- additional changes from version 1.0.0:
  * This version is equivalent to v0.3.7, but finally acknowledges
    that GitPython is stable and production ready
- additional changes from version 0.3.7:
  * IndexFile.add() will now write the index without any extension
    data by default
  * Renamed ignore_tree_extension_data keyword argument in
    IndexFile.write(...) to ignore_extension_data
  * If the git command executed during Remote.push(...)|fetch(...)
    returns with an non-zero exit code and GitPython didn't obtain
    any head-information, the corresponding GitCommandError will be
    raised
  * If the git executable can't be found in the PATH or at the path
    provided by GIT_PYTHON_GIT_EXECUTABLE, this is made obvious by
    throwing GitCommandNotFound, both on unix and on windows.
  * A list of all issues can be found on github
- additional changes from version 0.3.6:
  * special members like __init__ are now listed in the API
    documentation
  * tutorial section was revised entirely, more advanced examples
    were added
  * As rev_parse will now throw BadName as well as BadObject,
    client code will have to catch both exception types
  * Repo.working_tree_dir now returns None if it is bare
  * IndexFile.add() previously raised AssertionError when paths
    where used with bare repository, now it raises
    InvalidGitRepositoryError
  * Added Repo.merge_base() implementation. See the respective
    issue on github
  * [include] sections in git configuration files are now respected
  * Added GitConfigParser.rename_section()
  * Added Submodule.rename()
  * A list of all issues can be found on github
- additional changes from version 0.3.5:
  * push/pull/fetch operations will not block anymore
  * diff() can now properly detect renames, both in patch and raw
    format
  * repo.odb.update_cache() is now called automatically after fetch
    and pull operations
  * Repo(path) will not automatically search upstream anymore and
    find any git directory on its way up
  * IndexFile.commit() now runs the pre-commit and post-commit hooks
  * A list of all issues can be found on github
- additional changes from version 0.3.4:
  * Internally, hexadecimal SHA1 are treated as ascii encoded
    strings
  * Id attribute of Commit objects is now hexsha, instead of binsha
  * IMPORTANT: If you were using the config_writer(), you
    implicitly relied on __del__ to work as expected to flush
    changes. To be sure changes are flushed under PY3, you will
    have to call the new release() method to trigger a flush
  * The Tree now has a .join('name') method which is equivalent to
    tree / 'name'
- additional changes from version 0.3.3:
  * When fetching, pulling or pushing, and an error occours, it
    will not be reported on stdout anymore
  * Code Cleanup (in preparation for python 3 support)
- additional changes from version 0.3.2.1:
  * Fix for #207
- additional changes from version 0.3.2:
  * Release of most recent version as non-RC build, just to allow
    pip to install the latest version right away.
- update project URL
- point the source URL to pypi
- set a minimum version for python-gitdb and add it to
  BuildRequires to validate dependencies at build time.
- add python-ordereddict as dependency for SLE11 (python 2.6)
- remove outdated py_requires
* Thu Sep 26 2013 speilicke@suse.com
- Require git-core for the cgit backend (bnc#841684)
* Tue Jun 26 2012 saschpe@suse.de
- Spec file cleanup
* Wed Jul  6 2011 alexandre@exatati.com.br
- Update to 0.3.2.RC1;
- Regenerate spec file with py2pack;
- Building as noarch now.
* Tue Sep  7 2010 alexandre@exatati.com.br
- Update to 0.3.0-beta2;
- Bzip2 source file.
* Thu Jul  8 2010 alexandre@exatati.com.br
- Update to 0.3.0-beta1.
* Wed Apr  7 2010 alexandre@exatati.com.br
- Update to 0.2.0-beta1;
- Spec file cleaned with spec-cleaner.
* Tue Nov 24 2009 alexandre@exatati.com.br
- Initial pacakge (0.1.6) for openSUSE.
